.. _usage:

=====
Usage
=====

The pages in this section are simple examples of how to use the MICE estimator.

.. toctree::
    :maxdepth: 1


    getting_started/getting_started
    finite_case/finite_case
